@@ -275,7 +275,7 @@ char *egetcwd(char *buf, size_t size)
 			 */
 		  	errno = ENAMETOOLONG;
 
-		if (errno) {
+		if (errno && errno != EACCES) {
 		  	/* If getcwd() allocated the buffer, free it. */
 			if (NULL == oldbuf)
 				free(tmpbuf);
@@ -801,10 +801,8 @@ static int check_syscall(sbcontext_t *sbcontext, int sb_nr, const char *func,
 	bool access, debug, verbose;
 
 	absolute_path = resolve_path(file, 0);
-	if (NULL == absolute_path)
-		goto error;
 	resolved_path = resolve_path(file, 1);
-	if (NULL == resolved_path)
+	if (!absolute_path || !resolved_path)
 		goto error;
 
 	verbose = is_env_on(ENV_SANDBOX_VERBOSE);
@@ -851,7 +849,7 @@ static int check_syscall(sbcontext_t *sbcontext, int sb_nr, const char *func,
 
 	return result;
 
-error:
+ error:
 	/* The path is too long to be canonicalized, so just warn and let the
 	 * function handle it (see bugs #21766 #94630 #101728 #227947)
 	 */
@@ -862,8 +860,9 @@ error:
 	}
 
 	/* If we get here, something bad happened */
-	SB_EERROR("ISE ", "Unrecoverable error: %s\n\tabs_path: %s\n\tres_path: %s\n",
-		strerror(errno), absolute_path, resolved_path);
+	SB_EERROR("ISE ", "%s(%s): %s\n"
+		"\tabs_path: %s\n" "\tres_path: %s\n",
+		func, file, strerror(errno), absolute_path, resolved_path);
 	sb_abort();
 }
 
@@ -895,7 +894,6 @@ static pthread_mutex_t sb_syscall_lock = PTHREAD_MUTEX_INITIALIZER;
 
 bool before_syscall(int dirfd, int sb_nr, const char *func, const char *file, int flags)
 {
-	int old_errno = errno;
 	int result;
 //	static sbcontext_t sbcontext;
 	char at_file_buf[SB_PATH_MAX];
@@ -906,6 +904,8 @@ bool before_syscall(int dirfd, int sb_nr, const char *func, const char *file, in
 		return false;
 	}
 
+	save_errno();
+
 	/* The *at style functions have the following semantics:
 	 *	- dirfd = AT_FDCWD: same as non-at func: file is based on CWD
 	 *	- file is absolute: dirfd is ignored
@@ -917,8 +917,14 @@ bool before_syscall(int dirfd, int sb_nr, const char *func, const char *file, in
 		size_t at_len = sizeof(at_file_buf) - 1 - 1 - strlen(file);
 		sprintf(at_file_buf, "/proc/%i/fd/%i", getpid(), dirfd);
 		ssize_t ret = readlink(at_file_buf, at_file_buf, at_len);
-		if (ret == -1)
+		if (ret == -1) {
+			/* see comments at end of check_syscall() */
+			if (errno == ENAMETOOLONG) {
+				restore_errno();
+				return true;
+			}
 			return false;
+		}
 		at_file_buf[ret] = '/';
 		at_file_buf[ret + 1] = '\0';
 		strcat(at_file_buf, file);
@@ -978,7 +984,7 @@ bool before_syscall(int dirfd, int sb_nr, const char *func, const char *file, in
 		 *        fopen() and co, ETOOLONG, etc). */
 		errno = EACCES;
 	} else if (result == 1)
-		errno = old_errno;
+		restore_errno();
 
 	return result ? true : false;
 }
