@@ -20,8 +20,12 @@ static inline bool sb_fopen_pre_check(WRAPPER_ARGS_PROTO)
 
 		/* If we're trying to read, fail normally if file does not stat */
 		struct stat st;
-		if (-1 == stat(pathname, &st))
+		if (-1 == stat(pathname, &st)) {
+			if (is_env_on(ENV_SANDBOX_DEBUG))
+				SB_EINFO("EARLY FAIL", "  %s(%s): %s\n",
+					STRING_NAME, pathname, strerror(errno));
 			return false;
+		}
 
 		restore_errno();
 	}
