@@ -4,11 +4,11 @@
 #define FUNC_STR "%i, \"%s\", %i, %i, %x"
 #define FUNC_IMP dirfd, file, uid, gid, flags
 #define ARG_CNT 5
-#define ARG_USE "<dirfd> <file> <uid> <gid>, <flags>"
+#define ARG_USE "<dirfd> <file> <uid> <gid> <flags>"
 
 #define process_args() \
 	s = argv[i++]; \
-	int dirfd = atoi(s); \
+	int dirfd = at_get_fd(s); \
 	\
 	s = argv[i++]; \
 	char *file = s; \
@@ -20,7 +20,6 @@
 	gid_t gid = atoi(s); \
 	\
 	s = argv[i++]; \
-	int flags = 0; \
-	sscanf(s, "%i", &flags);
+	int flags = at_get_flags(s);
 
 #include "test-skel-0.c"
